@@ -8,7 +8,6 @@ import (
 	"strconv"
 
 	"github.com/derailed/k9s/internal/client"
-	"github.com/derailed/k9s/internal/vul"
 	appsv1 "k8s.io/api/apps/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -24,7 +23,7 @@ func (StatefulSet) Header(ns string) Header {
 	h := Header{
 		HeaderColumn{Name: "NAMESPACE"},
 		HeaderColumn{Name: "NAME"},
-		HeaderColumn{Name: "VS"},
+		HeaderColumn{Name: "VS", VS: true},
 		HeaderColumn{Name: "READY"},
 		HeaderColumn{Name: "SELECTOR", Wide: true},
 		HeaderColumn{Name: "SERVICE"},
@@ -34,9 +33,6 @@ func (StatefulSet) Header(ns string) Header {
 		HeaderColumn{Name: "VALID", Wide: true},
 		HeaderColumn{Name: "AGE", Time: true},
 	}
-	if vul.ImgScanner == nil {
-		h = append(h[:vulIdx], h[vulIdx+1:]...)
-	}
 
 	return h
 }
@@ -57,7 +53,7 @@ func (s StatefulSet) Render(o interface{}, ns string, r *Row) error {
 	r.Fields = Fields{
 		sts.Namespace,
 		sts.Name,
-		computeVulScore(&sts.Spec.Template.Spec),
+		computeVulScore(sts.ObjectMeta, &sts.Spec.Template.Spec),
 		strconv.Itoa(int(sts.Status.ReadyReplicas)) + "/" + strconv.Itoa(int(sts.Status.Replicas)),
 		asSelector(sts.Spec.Selector),
 		na(sts.Spec.ServiceName),
@@ -67,9 +63,6 @@ func (s StatefulSet) Render(o interface{}, ns string, r *Row) error {
 		AsStatus(s.diagnose(sts.Status.Replicas, sts.Status.ReadyReplicas)),
 		ToAge(sts.GetCreationTimestamp()),
 	}
-	if vul.ImgScanner == nil {
-		r.Fields = append(r.Fields[:vulIdx], r.Fields[vulIdx+1:]...)
-	}
 
 	return nil
 }
