@@ -167,7 +167,7 @@ func (c *Command) run(p *cmd.Interpreter, fqn string, clearStack bool) error {
 			return err
 		}
 
-		if err := c.app.switchContext(p); err != nil {
+		if err := c.app.switchContext(p, false); err != nil {
 			return err
 		}
 	}
